@@ -17,7 +17,6 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 #include "mmaid.h"
-#include "argument.h"
 #include "charlist.h"
 #include "command.h"
 #include "conf.h"
@@ -28,6 +27,7 @@
 #include "sigmain.h"
 #include "toolbar.h"
 #include "version.h"
+#include "misc/argument.h"
 #include "misc/fileio.h"
 #include "misc/license.h"
 #include "misc/profile.h"
@@ -130,10 +130,58 @@ DdemlCallback (UINT     uType,
               {
                 gboolean *arg_files;
                 gchar **argv;
-                gint i;
+                gint i, array[2], def[2];
+                ArgumentBool arg_n, arg_x;
+                ArgumentValue arg_h;
+                ArgumentArray arg_s;
+                ArgumentList arg_opts[] = {
+{"history", 'h',  "NUM",          N_("History"),     ARGUMENT_TYPE_VALUE, &arg_h},
+{"new",     'n',  "ON/OFF",       N_("New File"),    ARGUMENT_TYPE_BOOL,  &arg_n},
+{"size",    's',  "WIDTH,HEIGHT", N_("Window Size"), ARGUMENT_TYPE_ARRAY, &arg_s},
+{"second",  'x',  "ON/OFF",       N_("Open Window"), ARGUMENT_TYPE_BOOL,  &arg_x},
+{NULL,      '\0', NULL,           NULL,              0,                   NULL}};
 
+                /* ja:ファイルの履歴 */
+                arg_h.val = history;
+                arg_h.def = 4;
+                /* ja:新規ファイル */
+                arg_n.flag = newfile;
+                arg_n.def = FALSE;
+                /* ja:ウインドウサイズ */
+                array[0] = def_width;
+                array[1] = def_height;
+                def[0] = gdk_screen_width ()  * 2 / 3;
+                def[1] = gdk_screen_height () * 2 / 3;
+                arg_s.leng = 2;
+                arg_s.array = array;
+                arg_s.def = def;
+                /* ja:新規ウインドウ */
+                arg_x.flag = second;
+                arg_x.def = FALSE;
+                /* ja:コマンドラインの解析 */
                 argv = g_strsplit (text, "\n", G_MAXINT);
-                arg_files = arg_analyse (argv, FALSE);
+                arg_files = arg_analyse (argv, arg_opts);
+                if (history != arg_h.val && 0 <= arg_h.val && arg_h.val <= 10)
+                  {
+                    /* ja:履歴の整理 */
+                    GList *glist;
+                    GtkWidget *menu_shell;
+
+                    history = arg_h.val;
+                    menu_shell = gtk_item_factory_get_widget
+                                                (ifactory_menu, "<main>/File");
+                    glist = gtk_container_children
+                                                (GTK_CONTAINER (menu_shell));
+                    for (i = g_list_length (glist) - 3;
+                            i > history - (history == 0) + MENUFILE - 2; i--)
+                      gtk_container_remove (GTK_CONTAINER
+                                    (menu_shell), g_list_nth_data (glist, i));
+                    g_list_free (glist);
+                  }
+                newfile = arg_n.flag;
+                def_width = array[0];
+                def_height = array[1];
+                second = arg_x.flag;
                 for (i = 1; argv[i]; i++)
                   if (arg_files[i])
                     file_open_edit (argv[i]);
@@ -384,7 +432,54 @@ main (int argc, char *argv[])
     }
 
   /* ja:コマンドラインの解析 */
-  arg_files = arg_analyse (argv, TRUE);
+  {
+    gint array[2], def[2];
+    ArgumentBool arg_n, arg_x;
+    ArgumentValue arg_h;
+    ArgumentArray arg_s;
+    ArgumentExit arg_v;
+    ArgumentHelp arg_q;
+    ArgumentList arg_opts[] = {
+{"history", 'h',  "NUM",          N_("History"),     ARGUMENT_TYPE_VALUE, &arg_h},
+{"new",     'n',  "ON/OFF",       N_("New File"),    ARGUMENT_TYPE_BOOL,  &arg_n},
+{"size",    's',  "WIDTH,HEIGHT", N_("Window Size"), ARGUMENT_TYPE_ARRAY, &arg_s},
+{"second",  'x',  "ON/OFF",       N_("Open Window"), ARGUMENT_TYPE_BOOL,  &arg_x},
+{"version", 'v',  NULL,           N_("About"),       ARGUMENT_TYPE_EXIT,  &arg_v},
+{"help",    '?',  NULL,           N_("Help"),        ARGUMENT_TYPE_HELP,  &arg_q},
+{NULL,      '\0', NULL,           NULL,              0,                   NULL}};
+
+    /* ja:ファイルの履歴 */
+    arg_h.val = history;
+    arg_h.def = 4;
+    /* ja:新規ファイル */
+    arg_n.flag = newfile;
+    arg_n.def = FALSE;
+    /* ja:ウインドウサイズ */
+    array[0] = def_width;
+    array[1] = def_height;
+    def[0] = gdk_screen_width ()  * 2 / 3;
+    def[1] = gdk_screen_height () * 2 / 3;
+    arg_s.leng = 2;
+    arg_s.array = array;
+    arg_s.def = def;
+    /* ja:新規ウインドウ */
+    arg_x.flag = second;
+    arg_x.def = FALSE;
+    /* ja:バージョン */
+    arg_v.str =
+MMAID_VERSION_NOTICE"\n"
+MMAID_COPYRIGHT_NOTICE"\n"
+"This is free software; see the source for copying conditions.  There is NO\n"
+"warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n";
+    /* ja:ヘルプ */
+    arg_q.str = MMAID_COPYRIGHT_NOTICE"\n\n";
+    arg_files = arg_analyse (argv, arg_opts);
+    if (0 <= arg_h.val && arg_h.val <= 10)
+      history = arg_h.val;
+    def_width = array[0];
+    def_height = array[1];
+    second = arg_x.flag;
+  }
 
   /* ja:メインウインドウ */
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
