@@ -17,12 +17,12 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 #include <gdk/gdkkeysyms.h>
-#include "argument.h"
 #include "command.h"
 #include "file.h"
 #include "general.h"
 #include "mm_list.h"
 #include "sigmain.h"
+#include "misc/argument.h"
 #include "misc/misc.h"
 
 
@@ -278,15 +278,61 @@ signal_selection_received (GtkWidget        *widget,
     {
       gboolean *arg_files;
       gchar **argv;
-      gint i;
+      gint i, array[2], def[2];
+      ArgumentBool arg_n, arg_x;
+      ArgumentValue arg_h;
+      ArgumentArray arg_s;
+      ArgumentList arg_opts[] = {
+{"history", 'h',  "NUM",          N_("History"),     ARGUMENT_TYPE_VALUE, &arg_h},
+{"new",     'n',  "ON/OFF",       N_("New File"),    ARGUMENT_TYPE_BOOL,  &arg_n},
+{"size",    's',  "WIDTH,HEIGHT", N_("Window Size"), ARGUMENT_TYPE_ARRAY, &arg_s},
+{"second",  'x',  "ON/OFF",       N_("Open Window"), ARGUMENT_TYPE_BOOL,  &arg_x},
+{NULL,      '\0', NULL,           NULL,              0,                   NULL}};
 
       i = gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook));
       mmaid = i >= 0 ? g_object_get_data (G_OBJECT (gtk_notebook_get_nth_page
                             (GTK_NOTEBOOK (notebook), i)), "user_data") : NULL;
       /* ja:プロセス間通信 */
+      /* ja:ファイルの履歴 */
+      arg_h.val = history;
+      arg_h.def = 4;
+      /* ja:新規ファイル */
+      arg_n.flag = newfile;
+      arg_n.def = FALSE;
+      /* ja:ウインドウサイズ */
+      array[0] = def_width;
+      array[1] = def_height;
+      def[0] = gdk_screen_width ()  * 2 / 3;
+      def[1] = gdk_screen_height () * 2 / 3;
+      arg_s.leng = 2;
+      arg_s.array = array;
+      arg_s.def = def;
+      /* ja:新規ウインドウ */
+      arg_x.flag = second;
+      arg_x.def = FALSE;
       /* ja:コマンドラインの解析 */
       argv = g_strsplit (data->data, "\n", G_MAXINT);
-      arg_files = arg_analyse (argv, FALSE);
+      arg_files = arg_analyse (argv, arg_opts);
+      if (history != arg_h.val && 0 <= arg_h.val && arg_h.val <= 10)
+        {
+          /* ja:履歴の整理 */
+          GList *glist;
+          GtkWidget *menu_shell;
+
+          history = arg_h.val;
+          menu_shell = gtk_item_factory_get_widget
+                                                (ifactory_menu, "<main>/File");
+          glist = gtk_container_children (GTK_CONTAINER (menu_shell));
+          for (i = g_list_length (glist) - 3;
+                            i > history - (history == 0) + MENUFILE - 2; i--)
+            gtk_container_remove (GTK_CONTAINER
+                                    (menu_shell), g_list_nth_data (glist, i));
+          g_list_free (glist);
+        }
+      newfile = arg_n.flag;
+      def_width = array[0];
+      def_height = array[1];
+      second = arg_x.flag;
       for (i = 1; argv[i]; i++)
         if (arg_files[i])
           switch (file_is_type (argv[i]))
@@ -360,7 +406,7 @@ signal_key_press (GtkWidget   *widget,
 
       gtk_accelerator_parse (menu_accel[i].accelerator, &key, &mods);
       if (gdk_keyval_to_upper (event->keyval) == gdk_keyval_to_upper (key)
-													&& event->state == mods)
+                                                    && event->state == mods)
         {
           GtkWidget *widget;
 
